@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = 0.01;
+$VERSION = 0.02;
 @ISA = qw/Gedcom::Date/;
 
 use Gedcom::Date;
@@ -49,13 +49,24 @@ sub earliest {
     return $self->{date}->earliest;
 }
 
+my %text = (
+    en => 'about %0',
+    nl => 'rond %0',
+);
+
+sub text_format {
+    my ($self, $lang) = @_;
+
+    return ($text{$lang}, $self->{date});
+}
+
 1;
 
 __END__
 
 =head1 NAME
 
-Gedcom::Date::Approximated - Perl class for interpreting simple Gedcom dates
+Gedcom::Date::Approximated - Perl class for approximated Gedcom dates
 
 =head1 SYNOPSIS
 
